# Particle systems

For a system of particles we have the mutual forces among the selected particles referred to as internal forces, otherwise external forces. If there are no external forces, the system is called closed, otherwise open.

> *Definition 1*: the internal interaction forces $\mathbf{F}_i$ in a system of $n \in \mathbb{N}$ particles with position $\mathbf{x}_i$ may be approximated by pairwise interaction forces given by
>
> $$
>   \mathbf{F}_i (\mathbf{x}_i) = \sum_{j=1}^n \mathbf{F}_{ij}(\mathbf{x}_i, \mathbf{x}_j) \epsilon_{ij}, 
> $$
>
> for all $\mathbf{x}_i$ with $\mathbf{F}_{ij}$ the pairwise interaction force between particle $i$ and $j$. 

For high density systems this approximation diverges.

## Systems with conservative internal forces

Considering a system of $n \in \mathbb{N}$ particles with position $\mathbf{x}_i$ and mass $m_i \in \mathbb{R}$ with conservative external forces $\mathbf{F}_i$. For each particle an equation of motion can be formulated using the pairwise interaction approximation (definition 1), obtaining

$$
    m_i \mathbf{x}_i''(t) = \mathbf{F}_i(\mathbf{x}_i(t)) + \sum_{j=1}^n \mathbf{F}_{ij}(\mathbf{x}_i, \mathbf{x}_j) \epsilon_{ij},
$$

for all $t \in \mathbb{R}$ with $\mathbf{F}_{ij}$ the pairwise interaction force. 

> *Definition 2*: the total mass $M$ of the system is defined as
>
> $$
>   M = \sum_{i=1}^n m_i.
> $$

<br>

> *Definition 3*: the center of mass $\mathbf{R}: t \mapsto \mathbf{R}(t)$ of the system is defined as 
>
> $$
>   \mathbf{R}(t) = \frac{1}{M} \sum_{i=1}^n m_i \mathbf{x}_i(t),
> $$
>
> for all $t \in \mathbb{R}$. 

<br>

> *Definition 4*: the total momentum $\mathbf{P}$ and angular momentum $\mathbf{J}$ of the system are defined as
>
> $$
> \begin{align*}
>   \mathbf{P} &= \sum_{i=1}^n \mathbf{p}_i, \\
>   \mathbf{J} &= \sum_{i=1}^n \mathbf{x}_i \times \mathbf{p}_i,
> \end{align*}
> $$
>
> with $\mathbf{p}_i$ the momentum of each particle.

We have for $\mathbf{P}: t \mapsto \mathbf{P}(t)$ the total momentum equivalently given by

$$
    \mathbf{P}(t) = M \mathbf{R}'(t),
$$

for all $t \in \mathbb{R}$ with $\mathbf{R}: t \mapsto \mathbf{R}(t)$ the center of mass.

> *Definition 5*: the total external force $\mathbf{F}$ and torque $\mathbf{\Gamma}$ of the system are defined as
>
> $$
> \begin{align*}
>   \mathbf{F} &= \sum_{i=1}^n \mathbf{F}_i, \\
>   \mathbf{\Gamma} &= \sum_{i=1}^n \mathbf{x}_i \times \mathbf{F}_i,
> \end{align*}
> $$
>
> with $\mathbf{F}_i$ the conservative external force.

<br>

> *Proposition 1*: the total momentum $\mathbf{P}: t \mapsto \mathbf{P}(t)$ is related to the total external force $\mathbf{F}: t \mapsto \mathbf{F}(t)$ by
>
> $$
>   \mathbf{P}'(t) = \mathbf{F}(t),
> $$
>
> for all $t \in \mathbb{R}$.

??? note "*Proof*:"

    Will be adder later.

> *Proposition 2*: the total angular momentum $\mathbf{J}: t \mapsto \mathbf{J}(t)$ is related to the total external torque $\mathbf{\Gamma}: t \mapsto \mathbf{\Gamma}(t)$ by
>
> $$
>   \mathbf{J}'(t) = \mathbf{\Gamma}(t),
> $$
>
> for all $t \in \mathbb{R}$ if the internal forces are central forces.

??? note "*Proof*:"

    Will be adder later.

### Orbital and spin angular momentum

Considering internal position vectors $\mathbf{r}_i$ relative to the center of mass $\mathbf{r}_i = \mathbf{x}_i - \mathbf{R}$. I propose that the total angular momentum $\mathbf{J}$ can be expressed as a superposition of the orbital $\mathbf{L}$ and spin $\mathbf{S}$ angular momentum components given by

$$
    \mathbf{J} = \mathbf{L} + \mathbf{S}.
$$

??? note "*Proof*:"

    Will be added later.

> *Definition 6*: the orbital angular momentum $\mathbf{L}$ of the system is defined as
>
> $$
>   \mathbf{L} = \mathbf{R} \times \mathbf{P},
> $$
>
> with $\mathbf{R}$ the center of mass and $\mathbf{P}$ the total momentum of the system.

<br>

> *Definition 7*: the spin angular momentum $\mathbf{S}: t \mapsto \mathbf{S}(t)$ of the system is defined as
>
> $$
>   \mathbf{S}(t) = \sum_{i=1}^n \mathbf{r}_i(t) \times m_i \mathbf{r}'_i(t)
> $$
>
> for all $t \in \mathbb{R}$ with $\mathbb{r}_i$ the internal position. 

Analoguosly the orbital and spin torque may be defined. 

> *Definition 8*: the orbital and spin torque $\mathbf{\Gamma}_{o,s}$ of the system are defined as 
>
> $$
> \begin{align*}
>   \mathbf{\Gamma}_o &= \mathbf{R} \times \mathbf{F}, \\
>   \mathbf{\Gamma}_s &= \sum_{i=1}^n \mathbf{r}_i \times \mathbf{F}_i,
> \end{align*}
> $$
>
> with $\mathbf{R}$ the center of mass, $\mathbf{r}_i$ the internal position and $\mathbf{F}_i$ the conservative external force.

Similarly, the total torque $\mathbf{\Gamma}$ of the system is the superposition of the orbital and spin torque $\mathbf{\Gamma}_{o,s}$ given by

$$
    \mathbf{\Gamma} = \mathbf{\Gamma}_o + \mathbf{\Gamma}_s.
$$

??? note "*Proof*:"

    Will be added later.

> *Proposition 3*: let $\mathbf{L}: t \mapsto \mathbf{L}(t)$ be the orbital angular momentum and let $\mathbf{S}: t \mapsto \mathbf{S}(t)$ be the spin angular momentum. Then we have
>
> $$
> \begin{align*}
>   \mathbf{L}'(t) &= \mathbf{\Gamma}_o(t), \\
>   \mathbf{S}'(t) &= \mathbf{\Gamma}_s(t),
> \end{align*}
> $$
>
> for all $t \in \mathbb{R}$ with $\mathbf{\Gamma}_o: t \mapsto \mathbf{\Gamma}_o(t)$ and $\mathbf{\Gamma}_s: t \mapsto \mathbf{\Gamma}_s(t)$ the orbital and spin torque.

### Energy

> *Definition 9*: the total kinetic energy $T$ of the system is defined as 
>
> $$
>   T = \sum_{i=1}^n \frac{1}{2} m_i \|\mathbf{x}_i'\|^2,
> $$
>
> with $\mathbf{x}_i$ the position of each particle.

<br>

> *Definition 10*: the orbital and internal kinetic energy $T_{o,r}$ of the system are defined as 
>
> $$
> \begin{align*}
>   T_o = \frac{1}{2} M \|\mathbf{R}\|^2, \\
>   T_r = \sum_{i=1}^n \frac{1}{2} m_i \|\mathbf{r}_i'\|^2,
> \end{align*}
> $$
>
> with $M$ the total mass, $\mathbf{R}$ the center of mass and $\mathbf{r}$ the internal position of each particle.

<br>

> *Proposition 4*: the total kinetic energy $T$ of the system is a superposition of the orbital and internal kinetic energy given by
>
> $$
>   T = T_o + T_r.
> $$

??? note "*Proof*:"

    Will be added later.

> *Proposition 5*: the dynamics of the orbital and kinetic energy $T_o: t \mapsto T_o(t)$ is decoupled
>
> $$
>   T_o'(t) = \langle \mathbf{F}, \mathbf{R}'(t) \rangle,
> $$
>
> for all $t \in \mathbb{R}$ with $\mathbf{F}$ the total external force and $\mathbf{R}$ the center of mass.
>
> The dynamics of the internal kinetic energy $T_r: t \mapsto T_r(t)$ is not decoupled
>
> $$
>   T_r'(t) = \sum_{i=1}^n \langle \mathbf{f}_i, \mathbf{r}_i'(t) \rangle,
> $$
>
> for all $t \in \mathbb{R}$ with $\mathbf{f}_i$ the sum of both external and internal forces for each particle. 

??? note "*Proof*:"

    Will be added later.